@@ -1,4 +1,4 @@
 from python_helper import Constant as c
 
-URI_TERM = 'healt'
+URI_TERM = 'health'
 URI = f'{c.SLASH}{URI_TERM}'
